Observer4<A, B, C, D> class

A widget that observes changes in four reactive variables and triggers a rebuild when any of the variables changes.

Inheritance
Annotations
  • @Deprecated('Use ReactiveBuilder instead. Observer4 will be removed in a future version.')

Constructors

Observer4({Key? key, required Reactive<A> listenable, required Reactive<B> listenable2, required Reactive<C> listenable3, required Reactive<D> listenable4, required Widget listener(A data1, B data2, C data3, D data4)})
Constructs an Observer4 widget.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listenable → Reactive<A>
The first reactive variable to listen to for changes.
final
listenable2 → Reactive<B>
The second reactive variable to listen to for changes.
final
listenable3 → Reactive<C>
The third reactive variable to listen to for changes.
final
listenable4 → Reactive<D>
The fourth reactive variable to listen to for changes.
final
listener → Widget Function(A data1, B data2, C data3, D data4)
A callback function that defines the widget to rebuild whenever any of the reactive variables changes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited