builder property

Widget Function(BuildContext context, T value) builder
final

Builder function called with the current value whenever it changes.

This function should return the widget tree to display based on value.

Implementation

final Widget Function(BuildContext context, T value) builder;