ReactiveStateWidget<T> class abstract

An abstract class for creating reactive views.

Extend the ReactiveWidget class to create a reactive view that depends on a specific controller type. The controller instance can be accessed using the controller getter.

Inheritance

Constructors

ReactiveStateWidget({Key? key, String? tag})
Creates a reactive view.
const

Properties

controller → T
Retrieves the controller instance associated with this widget.
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
A tag that can be used to differentiate between multiple instances of the same controller type.
final

Methods

bindController() → BindController<T>?
Binds a controller instance to this widget.
build(BuildContext context) → Widget
Builds the widget's user interface.
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ReactiveStateWidget<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
Called when the widget is about to be disposed.
initState() → void
Called when the widget is first created.
initStateWithContext(BuildContext context) → void
Called one frame after initState.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited