MultiReactiveBuilder constructor
const
MultiReactiveBuilder({})
Creates a MultiReactiveBuilder widget.
The reactives parameter is a list of reactive variables to observe.
The builder callback builds the widget tree and is called whenever
any of the reactive variables changes.
The optional listener callback is invoked for side effects.
The optional buildWhen callback determines whether to rebuild the widget.
The optional listenWhen callback determines whether to invoke the listener.
Implementation
const MultiReactiveBuilder({
Key? key,
required this.reactives,
required this.builder,
this.listener,
this.buildWhen,
this.listenWhen,
}) : super(key: key);